@@ -16,6 +16,19 @@ class TextProvider(BaseProvider):
             "legend": self.get_legend()
         }
 
+
+class PictureTextProvider(TextProvider):
+    def get_picture(self):
+        raise NotImplementedError
+
+    def compute(self):
+        return {
+            "data": self.get_data(),
+            "legend": self.get_legend(),
+            "picture": self.get_picture()
+        }
+
+
 class DonutProvider(BaseProvider):
     def get_legend(self):
         raise NotImplementedError
@@ -30,6 +43,23 @@ class DonutProvider(BaseProvider):
         }
 
 
+class EvolutionProvider(BaseProvider):
+    def get_data(self):
+        raise NotImplementedError
+
+    def get_legend(self):
+        raise NotImplementedError
+
+    def get_points(self):
+        raise NotImplementedError
+
+    def compute(self):
+        return {
+            "data": self.get_data(),
+            "legend": self.get_legend(),
+            "points": self.get_points()
+        }
+
 class BarProvider(BaseProvider):
     def get_points(self):
         raise NotImplementedError
